==> archey4-4.13.4.tar.gz: archey4-4.13.4/archey/logos/darwin.py <==
"""Darwin (macOS) logo"""

from archey.colors import Colors


COLORS = [Colors.WHITE_NORMAL]

LOGO = [
    """{c[0]}                     c.'       """,
    """{c[0]}                  ,xNMM.       """,
    """{c[0]}                .OMMMMo        """,
    """{c[0]}                lMMM"          """,
    """{c[0]}      .;loddo:.  .olloddol;.   """,
    """{c[0]}    cKMMMMMMMMMMNWMMMMMMMMMM0: """,
    """{c[0]}  .KMMMMMMMMMMMMMMMMMMMMMMMWd. """,
    """{c[0]}  XMMMMMMMMMMMMMMMMMMMMMMMX.   """,
    """{c[0]}  MMMMMMMMMMMMMMMMMMMMMMMM:    """,
    """{c[0]}  MMMMMMMMMMMMMMMMMMMMMMMM:    """,
    """{c[0]}  MMMMMMMMMMMMMMMMMMMMMMMMX.   """,
    """{c[0]}  kMMMMMMMMMMMMMMMMMMMMMMMMWd. """,
    """{c[0]}  'XMMMMMMMMMMMMMMMMMMMMMMMMMMk""",
    """{c[0]}   'XMMMMMMMMMMMMMMMMMMMMMMMMK.""",
    """{c[0]}     kMMMMMMMMMMMMMMMMMMMMMMd  """,
    """{c[0]}      ;KMMMMMMMWXXWMMMMMMMk.   """,
    """{c[0]}        "cooc*"    "*coo'"     """
]

# Alternative logo : Apple's "retro" logo.

COLORS_RETRO = [
    Colors.CYAN_BRIGHT,
    Colors.GREEN_BRIGHT,
    Colors.YELLOW_BRIGHT,
    Colors.YELLOW_NORMAL,
    Colors.RED_BRIGHT,
    Colors.MAGENTA_BRIGHT,
    Colors.BLUE_BRIGHT
]

LOGO_RETRO = [
    """{c[0]}               {c[1]}###{c[0]}       """,
    """{c[0]}             {c[1]}####{c[0]}        """,
    """{c[0]}             {c[1]}###{c[0]}         """,
    """{c[0]}     {c[1]}#######{c[0]}    {c[1]}#######{c[0]}  """,
    """{c[0]}   {c[2]}######################{c[0]}""",
    """{c[0]}  {c[2]}#####################{c[0]}  """,
    """{c[0]}  {c[4]}####################{c[0]}   """,
    """{c[0]}  {c[4]}####################{c[0]}   """,
    """{c[0]}  {c[4]}#####################{c[0]}  """,
    """{c[0]}   {c[5]}######################{c[0]}""",
    """{c[0]}    {c[5]}####################{c[0]} """,
    """{c[0]}      {c[6]}################{c[0]}   """,
    """{c[0]}       {c[6]}####{c[0]}     {c[6]}#####{c[0]}    """
]

==> archey4-4.14.1.0.tar.gz: archey4-4.14.1.0/archey/logos/darwin.py <==
"""Darwin (macOS) logo"""

from archey.colors import Colors

COLORS = [Colors.WHITE_NORMAL]

LOGO = [
    """{c[0]}                     c.'       """,
    """{c[0]}                  ,xNMM.       """,
    """{c[0]}                .OMMMMo        """,
    """{c[0]}                lMMM"          """,
    """{c[0]}      .;loddo:.  .olloddol;.   """,
    """{c[0]}    cKMMMMMMMMMMNWMMMMMMMMMM0: """,
    """{c[0]}  .KMMMMMMMMMMMMMMMMMMMMMMMWd. """,
    """{c[0]}  XMMMMMMMMMMMMMMMMMMMMMMMX.   """,
    """{c[0]}  MMMMMMMMMMMMMMMMMMMMMMMM:    """,
    """{c[0]}  MMMMMMMMMMMMMMMMMMMMMMMM:    """,
    """{c[0]}  MMMMMMMMMMMMMMMMMMMMMMMMX.   """,
    """{c[0]}  kMMMMMMMMMMMMMMMMMMMMMMMMWd. """,
    """{c[0]}  'XMMMMMMMMMMMMMMMMMMMMMMMMMMk""",
    """{c[0]}   'XMMMMMMMMMMMMMMMMMMMMMMMMK.""",
    """{c[0]}     kMMMMMMMMMMMMMMMMMMMMMMd  """,
    """{c[0]}      ;KMMMMMMMWXXWMMMMMMMk.   """,
    """{c[0]}        "cooc*"    "*coo'"     """,
]

# Alternative logo : Apple's "retro" logo.

COLORS_RETRO = [
    Colors.CYAN_BRIGHT,
    Colors.GREEN_BRIGHT,
    Colors.YELLOW_BRIGHT,
    Colors.YELLOW_NORMAL,
    Colors.RED_BRIGHT,
    Colors.MAGENTA_BRIGHT,
    Colors.BLUE_BRIGHT,
]

LOGO_RETRO = [
    """{c[0]}               {c[1]}###{c[0]}       """,
    """{c[0]}             {c[1]}####{c[0]}        """,
    """{c[0]}             {c[1]}###{c[0]}         """,
    """{c[0]}     {c[1]}#######{c[0]}    {c[1]}#######{c[0]}  """,
    """{c[0]}   {c[2]}######################{c[0]}""",
    """{c[0]}  {c[2]}#####################{c[0]}  """,
    """{c[0]}  {c[4]}####################{c[0]}   """,
    """{c[0]}  {c[4]}####################{c[0]}   """,
    """{c[0]}  {c[4]}#####################{c[0]}  """,
    """{c[0]}   {c[5]}######################{c[0]}""",
    """{c[0]}    {c[5]}####################{c[0]} """,
    """{c[0]}      {c[6]}################{c[0]}   """,
    """{c[0]}       {c[6]}####{c[0]}     {c[6]}#####{c[0]}    """,
]
